package org.implab.gradle.containers.tasks;

import org.gradle.api.file.RegularFileProperty;
import org.gradle.api.provider.SetProperty;
import org.gradle.api.tasks.Internal;

/**
 * Base task for compose subtasks like 'uo', 'rm', 'stop', etc.
 */
public abstract class ComposeTask extends DockerCliTask {

    /** The list of profiles to use with the compose commands */
    @Internal
    public abstract SetProperty<String> getProfiles();

    /**
     * The primary compose files. This task is executed regardless whether these
     * files was changed.
     */
    @Internal
    public abstract RegularFileProperty getComposeFile();

    protected ComposeTask() {
        // the task can only be evaluated if the compose file is present
        setOnlyIf(self -> {
            var composeFile = getComposeFile().get().getAsFile();
            var exists = composeFile.exists();
            getLogger().info("file: {} {}", composeFile.toString(), exists ? "exists" : "doesn't exist");
            return exists;
        });
    }

}
